@@ -6,7 +6,7 @@ Mojolicious::Plugin::CGI - Run CGI script from Mojolicious
 
 =head1 VERSION
 
-0.20
+0.21
 
 =head1 DESCRIPTION
 
@@ -62,7 +62,7 @@ use constant DEBUG                => $ENV{MOJO_PLUGIN_CGI_DEBUG} || 0;
 use constant READ                 => 0;
 use constant WRITE                => 1;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 our %ORIGINAL_ENV = %ENV;
 
 =head1 ATTRIBUTES
@@ -200,10 +200,11 @@ sub register {
       my $pid;
 
       $c->$before;
-      defined($pid = fork) or die "Failed to fork: $!";
+      defined($pid = fork) or die "[CGI] Could not fork $name: $!";
 
       unless ($pid) {
-        Mojo::IOLoop->reset;
+
+        # No need to Mojo::IOLoop->reset, since the CGI script is started with exec()
         my @STDERR = @stderr ? ('>&', fileno $stderr[WRITE]) : ('>>', $self->{errlog});
         warn "[CGI:$name:$$] <<< (@{[$stdin->slurp]})\n" if DEBUG;
         %ENV = $self->emulate_environment($c);
